Calculate the percentage of the normative population with j or more abnormal test scores
Source:R/aborm_j_battery.R
aborm_j_battery.RdThis function calculates the percentage of the normative population that would exhibit j or more abnormal test scores in a battery of tests. The method uses multivariate normal simulation.
Value
A list containing:
- props
Proportion of individuals with more than j-1 abnormal scores.
- props.two.tail
Proportion of individuals with more than j-1 abnormal scores, adjusted for a two-tailed test.
Examples
# Example usage with a 4x4 identity matrix as the correlation matrix
R <- diag(4)
aborm_j_battery(R)
#> Abnormality of j abnormal scores in a battery of tests.
#>
#> Parameters:
#>
#> k: 4
#> Number of simulations: 1e+05
#> Abnormality threshold: z = -1.645
#>
#> Output (One-Tailed):
#>
#> Proportion of people with more than:
#> 0 abnormal scores: 18.71%
#> 1 abnormal scores: 1.31%
#> 2 abnormal scores: 0.05%
#> 3 abnormal scores: 0.00%
#>
#> Output (Two-Tailed):
#>
#> Proportion of people with more than:
#> 0 abnormal scores: 37.43%
#> 1 abnormal scores: 2.63%
#> 2 abnormal scores: 0.09%
#> 3 abnormal scores: 0.00%