Skip to contents

This function calculates the standard error of the predicted score with Crawford adjustment.

Usage

se_n1(sd.1, sd.2, r, n, t1.score, t2.score, norm.t1.mean)

Arguments

sd.1

Standard deviation of the first variable.

sd.2

Standard deviation of the second variable.

r

Reliability coefficient (reliability of the test).

n

Sample size.

t1.score

Score of the first test.

t2.score

Score of the second test.

norm.t1.mean

Mean of the norm group for the first test.

Value

The standard error for sample size n=1.

Examples

# Example usage:
se_n1(sd.1 = 3, sd.2 = 4, r = 0.8, n = 100, t1.score = 75, norm.t1.mean = 70)
#> [1] 2.278221