Skip to contents

This function calculates the standard error of prediction based on the provided standard deviations and the reliability coefficient.

Usage

se_prediction(sd.1, sd.2, r)

Arguments

sd.1

Standard deviation of the first variable.

sd.2

Standard deviation of the second variable.

r

Reliability coefficient (reliability of the test).

Value

The standard error of prediction.

Examples

# Single values
se_prediction(3, 4, 0.8)
#> [1] 2.236068

# Vectors
se_prediction(c(3, 2, 4), c(4, 3, 5), 0.8)
#> [1] 0.6324555