This function calculates the percentile of a given value in a dataset using one of three methods: "a", "b", or "c".
Examples
data <- c(1, 2, 3, 4, 5)
percentile(data, 3, method = "c")
#> [1] 50
This function calculates the percentile of a given value in a dataset using one of three methods: "a", "b", or "c".
data <- c(1, 2, 3, 4, 5)
percentile(data, 3, method = "c")
#> [1] 50