This function calculates the prevalence based on a given z-score.
Arguments
- z
A numeric value representing the z-score.
- method
A character string specifying the method to calculate prevalence. It must be one of "percentage", "proportion", or "ratio" (default: "ratio").
- two.tailed
Logical indicating whether to consider both tails of the distribution when calculating prevalence (default: FALSE).
- dp
Integer specifying the number of decimal places for the result (default: 5).