Calculate the standard error of the mean given the standard deviation and sample size, or calculate from data.
Examples
# If dat is provided, calculate sd and n from dat
se_mean(c(1, 2, 3, 4, 5))
#> [1] 0.7071068
# If sd and n are provided
se_mean(sd = 3, n = 30)
#> [1] 0.5477226
# If dat is not provided but sd and n are provided
se_mean(sd = 3, n = 30)
#> [1] 0.5477226